@@ -359,8 +359,7 @@ class Program(object):
                 m = Media(filename)
                 PROGRAMS.zadd(
                     self.redis_zset_key,
-                    '{}:{}'.format(m.filepath, index),
-                    timestamp
+                    {'{}:{}'.format(m.filepath, index): timestamp}
                     )
                 journal.send(
                     '{}:{} = {}'.format(m.filepath, index, timestamp),
